@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: smart-bookmarks-extension.c,v 1.12 2005/01/28 22:30:33 chpe Exp $
+ *  $Id: smart-bookmarks-extension.c,v 1.17 2005/11/02 21:41:41 chpe Exp $
  */
 
 #include "config.h"
@@ -178,15 +178,15 @@ search_smart_bookmark_cb (GtkAction *action,
 	id = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (action), NODE_ID_KEY));
 	g_return_if_fail (id != 0);
 
-	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
+	bookmarks = ephy_shell_get_bookmarks (ephy_shell_get_default ());
 	bmk = ephy_bookmarks_get_from_id (bookmarks, id);
-	g_return_if_fail (bmk != NULL);
+	if (bmk == NULL) return;
 
 	bmk_url =  ephy_node_get_property_string (bmk, EPHY_NODE_BMK_PROP_LOCATION);
 	g_return_if_fail (bmk_url != NULL);
 
 	/* Use smart bookmark solver to build definitive url */
-	url = ephy_bookmarks_solve_smart_url (bookmarks, bmk_url, text);
+	url = ephy_bookmarks_resolve_address (bookmarks, bmk_url, text);
 
 	if (url != NULL)
 	{
@@ -233,7 +233,8 @@ context_menu_cb (EphyEmbed *embed,
 	action = gtk_action_group_get_action (data->action_group, LOOKUP_ACTION);
 	g_return_val_if_fail (action != NULL, FALSE);
 
-	g_object_set(action, "sensitive", can_copy, "visible", can_copy, NULL);
+	gtk_action_set_sensitive (action, can_copy);
+	gtk_action_set_visible (action, can_copy);
 
 	return FALSE;
 }
@@ -310,17 +311,11 @@ rebuild_ui (WindowData *data)
 			       LOOKUP_ACTION "Menu", LOOKUP_ACTION,
 			       GTK_UI_MANAGER_MENU, FALSE);
 
-	/* Add bookmarks to popup context (framed document) */
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFramedDocumentPopup",
+	/* Add bookmarks to input popup context */
+	gtk_ui_manager_add_ui (manager, ui_id, "/EphyInputPopup",
 			       "SmbExtSep0", NULL,
 			       GTK_UI_MANAGER_SEPARATOR, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFramedDocumentPopup",
-			       LOOKUP_ACTION "Menu", LOOKUP_ACTION,
-			       GTK_UI_MANAGER_MENU, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFullscreenFramedDocumentPopup",
-			       "SmbExtSep0", NULL,
-			       GTK_UI_MANAGER_SEPARATOR, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id, "/EphyFullscreenFramedDocumentPopup",
+	gtk_ui_manager_add_ui (manager, ui_id, "/EphyInputPopup",
 			       LOOKUP_ACTION "Menu", LOOKUP_ACTION,
 			       GTK_UI_MANAGER_MENU, FALSE);
 
@@ -346,16 +341,12 @@ rebuild_ui (WindowData *data)
 				       "/EphyDocumentPopup/" LOOKUP_ACTION "Menu",
 				       verb, verb,
 				       GTK_UI_MANAGER_MENUITEM, FALSE);
-		gtk_ui_manager_add_ui (manager, ui_id,
-				       "/EphyFramedDocumentPopup/" LOOKUP_ACTION "Menu",
-				       verb, verb,
-				       GTK_UI_MANAGER_MENUITEM, FALSE);
 		gtk_ui_manager_add_ui (manager, ui_id,
 				       "/EphyFullscreenDocumentPopup/" LOOKUP_ACTION "Menu",
 				       verb, verb,
 				       GTK_UI_MANAGER_MENUITEM, FALSE);
 		gtk_ui_manager_add_ui (manager, ui_id,
-				       "/EphyFullscreenFramedDocumentPopup/" LOOKUP_ACTION "Menu",
+				       "/EphyInputPopup/" LOOKUP_ACTION "Menu",
 				       verb, verb,
 				       GTK_UI_MANAGER_MENUITEM, FALSE);
 	}
@@ -372,12 +363,8 @@ rebuild_ui (WindowData *data)
 			       GDICT_ACTION "FSIDP", GDICT_ACTION,
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
 	gtk_ui_manager_add_ui (manager, ui_id,
-			       "/EphyFramedDocumentPopup/" LOOKUP_ACTION "Menu",
-			       GDICT_ACTION "IFDP", GDICT_ACTION,
-			       GTK_UI_MANAGER_MENUITEM, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id,
-			       "/EphyFullscreenFramedDocumentPopup/" LOOKUP_ACTION "Menu",
-			       GDICT_ACTION "FSIFDP", GDICT_ACTION,
+			       "/EphyInputPopup/" LOOKUP_ACTION "Menu",
+			       GDICT_ACTION "INPUTP", GDICT_ACTION,
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
 
 	gtk_ui_manager_ensure_update (manager);
@@ -571,7 +558,7 @@ connect_proxy_cb (GtkActionGroup *action_group,
 	}
 }
 
-static GtkActionEntry action_entries [] =
+static const GtkActionEntry action_entries [] =
 {
 	{ LOOKUP_ACTION,
 	  NULL,
