@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab-grouper.c,v 1.1.2.3 2004/11/27 23:46:15 chpe Exp $
+ *  $Id: ephy-tab-grouper.c,v 1.7 2005/10/02 19:22:43 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-tab-grouper.h"
 #include "ephy-debug.h"
@@ -135,8 +133,6 @@ ephy_tab_grouper_set_notebook (EphyTabGrouper *grouper,
 	g_signal_connect_swapped (notebook, "switch_page", 
 				  G_CALLBACK (reset_last_tab), grouper);
 	g_signal_connect_swapped (notebook, "tabs_reordered", 
-				  G_CALLBACK (reset_last_tab), grouper);	
-	g_signal_connect_swapped (notebook, "tab_delete", 
 				  G_CALLBACK (reset_last_tab), grouper);
 }
 
@@ -145,7 +141,7 @@ ephy_tab_grouper_init (EphyTabGrouper *grouper)
 {
 	grouper->priv = EPHY_TAB_GROUPER_GET_PRIVATE (grouper);
 
-	LOG ("EphyTabGrouper initialised")
+	LOG ("EphyTabGrouper initialised");
 }
 
 static void
@@ -158,7 +154,7 @@ ephy_tab_grouper_finalize (GObject *object)
 		(grouper->priv->notebook, G_SIGNAL_MATCH_DATA,
 		 0, 0, NULL, NULL, grouper);
 
-	LOG ("EphyTabGrouper finalised")
+	LOG ("EphyTabGrouper finalised");
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
